@@ -47,11 +47,15 @@ def config():
     prompt="MAC address of the device",
     help="MAC address of the device.",
 )
-def read_config(ip, mac):
+@click.option("--token", prompt="Token of the device", help="Token of the device.")
+def read_config(ip, mac, token):
     """Read the current configuration of a myStrom device."""
     click.echo("Read configuration from %s" % ip)
     try:
-        request = requests.get("http://{}/{}/{}/".format(ip, URI, mac), timeout=TIMEOUT)
+        headers = {"Token": token} if token else {}
+        request = requests.get(
+            "http://{}/{}/{}/".format(ip, URI, mac), timeout=TIMEOUT, headers=headers
+        )
         click.echo(request.json())
     except requests.exceptions.ConnectionError:
         click.echo("Communication issue with the device")
@@ -71,6 +75,7 @@ def button():
     prompt="MAC address of the button",
     help="MAC address of the button.",
 )
+@click.option("--token", prompt="Token of the device", help="Token of the device.")
 @click.option(
     "--single",
     prompt="URL for a single tap",
@@ -87,7 +92,7 @@ def button():
     "--long", prompt="URL for a long tab", default="", help="URL for a long tab."
 )
 @click.option("--touch", prompt="URL for a touch", default="", help="URL for a touch.")
-def write_config(ip, mac, single, double, long, touch):
+def write_config(ip, mac, token, single, double, long, touch):
     """Write the current configuration of a myStrom button."""
     click.echo("Write configuration to device %s" % ip)
     data = {
@@ -97,8 +102,12 @@ def write_config(ip, mac, single, double, long, touch):
         "touch": touch,
     }
     try:
+        headers = {"Token": token} if token else {}
         request = requests.post(
-            "http://{}/{}/{}/".format(ip, URI, mac), data=data, timeout=TIMEOUT
+            "http://{}/{}/{}/".format(ip, URI, mac),
+            data=data,
+            timeout=TIMEOUT,
+            headers=headers,
         )
 
         if request.status_code == 200:
@@ -116,6 +125,7 @@ def write_config(ip, mac, single, double, long, touch):
     prompt="MAC address of the button",
     help="MAC address of the button.",
 )
+@click.option("--token", prompt="Token of the device", help="Token of the device.")
 @click.option(
     "--hass",
     prompt="IP address of the Home Assistant instance",
@@ -133,7 +143,7 @@ def write_config(ip, mac, single, double, long, touch):
     default="",
     help="ID of the myStrom button.",
 )
-def write_ha_config(ip, mac, hass, port, id):
+def write_ha_config(ip, mac, token, hass, port, id):
     """Write the configuration for Home Assistant to a myStrom button."""
     click.echo("Write configuration for Home Assistant to device %s..." % ip)
 
@@ -145,8 +155,12 @@ def write_ha_config(ip, mac, hass, port, id):
         "touch": action.format("touch", hass, port, id),
     }
     try:
+        headers = {"Token": token} if token else {}
         request = requests.post(
-            "http://{}/{}/{}/".format(ip, URI, mac), data=data, timeout=TIMEOUT
+            "http://{}/{}/{}/".format(ip, URI, mac),
+            data=data,
+            timeout=TIMEOUT,
+            headers=headers,
         )
 
         if request.status_code == 200:
@@ -170,7 +184,8 @@ def write_ha_config(ip, mac, hass, port, id):
     prompt="MAC address of the button",
     help="MAC address of the Wifi Button.",
 )
-def reset_config(ip, mac):
+@click.option("--token", prompt="Token of the device", help="Token of the device.")
+def reset_config(ip, mac, token):
     """Reset the current configuration of a myStrom WiFi Button."""
     click.echo("Reset configuration of button %s..." % ip)
     data = {
@@ -180,8 +195,12 @@ def reset_config(ip, mac):
         "touch": "",
     }
     try:
+        headers = {"Token": token} if token else {}
         request = requests.post(
-            "http://{}/{}/{}/".format(ip, URI, mac), data=data, timeout=TIMEOUT
+            "http://{}/{}/{}/".format(ip, URI, mac),
+            data=data,
+            timeout=TIMEOUT,
+            headers=headers,
         )
 
         if request.status_code == 200:
@@ -201,11 +220,15 @@ def reset_config(ip, mac):
     prompt="MAC address of the button",
     help="MAC address of the Wifi Button.",
 )
-def read_config(ip, mac):
+@click.option("--token", prompt="Token of the device", help="Token of the device.")
+def read_config(ip, mac, token):
     """Read the current configuration of a myStrom WiFi Button."""
     click.echo("Read the configuration of button %s..." % ip)
     try:
-        request = requests.get("http://{}/{}/{}/".format(ip, URI, mac), timeout=TIMEOUT)
+        headers = {"Token": token} if token else {}
+        request = requests.get(
+            "http://{}/{}/{}/".format(ip, URI, mac), timeout=TIMEOUT, headers=headers
+        )
         click.echo(request.json())
     except requests.exceptions.ConnectionError:
         click.echo("Communication issue with the device. No action performed")
@@ -222,9 +245,10 @@ def bulb():
 @click.option(
     "--mac", prompt="MAC address of the bulb", help="MAC address of the bulb."
 )
-async def on(ip, mac):
+@click.option("--token", prompt="Token of the device", help="Token of the device.")
+async def on(ip, mac, token):
     """Switch the bulb on."""
-    async with MyStromBulb(ip, mac) as bulb:
+    async with MyStromBulb(ip=ip, mac=mac, token=token) as bulb:
         await bulb.set_color_hex("00FFFFFF")
 
 
@@ -234,6 +258,7 @@ async def on(ip, mac):
 @click.option(
     "--mac", prompt="MAC address of the bulb", help="MAC address of the bulb."
 )
+@click.option("--token", prompt="Token of the device", help="Token of the device.")
 @click.option(
     "--hue", prompt="Set the hue of the bulb", help="Set the hue of the bulb."
 )
@@ -247,9 +272,9 @@ async def on(ip, mac):
     prompt="Set the value of the bulb",
     help="Set the value of the bulb.",
 )
-async def color(ip, mac, hue, saturation, value):
+async def color(ip, mac, token, hue, saturation, value):
     """Switch the bulb on with the given color."""
-    async with MyStromBulb(ip, mac) as bulb:
+    async with MyStromBulb(ip=ip, mac=mac, token=token) as bulb:
         await bulb.set_color_hsv(hue, saturation, value)
 
 
@@ -259,9 +284,10 @@ async def color(ip, mac, hue, saturation, value):
 @click.option(
     "--mac", prompt="MAC address of the bulb", help="MAC address of the bulb."
 )
-async def off(ip, mac):
+@click.option("--token", prompt="Token of the device", help="Token of the device.")
+async def off(ip, mac, token):
     """Switch the bulb off."""
-    async with MyStromBulb(ip, mac) as bulb:
+    async with MyStromBulb(ip=ip, mac=mac, token=token) as bulb:
         await bulb.set_off()
 
 
@@ -271,15 +297,16 @@ async def off(ip, mac):
 @click.option(
     "--mac", prompt="MAC address of the bulb", help="MAC address of the bulb."
 )
+@click.option("--token", prompt="Token of the device", help="Token of the device.")
 @click.option(
     "--time",
     prompt="Time to flash",
     help="Time to flash the bulb in seconds.",
     default=10,
 )
-async def flash(ip, mac, time):
+async def flash(ip, mac, token, time):
     """Flash the bulb off."""
-    async with MyStromBulb(ip, mac) as bulb:
+    async with MyStromBulb(ip=ip, mac=mac, token=token) as bulb:
         await bulb.set_flashing(time, [100, 50, 30], [200, 0, 71])
 
 
@@ -289,15 +316,16 @@ async def flash(ip, mac, time):
 @click.option(
     "--mac", prompt="MAC address of the bulb", help="MAC address of the bulb."
 )
+@click.option("--token", prompt="Token of the device", help="Token of the device.")
 @click.option(
     "--time",
     prompt="Time for the complete rainbow",
     help="Time to perform the rainbow in seconds.",
     default=30,
 )
-async def rainbow(ip, mac, time):
+async def rainbow(ip, mac, token, time):
     """Let the buld change the color and show a rainbow."""
-    async with MyStromBulb(ip, mac) as bulb:
+    async with MyStromBulb(ip=ip, mac=mac, token=token) as bulb:
         await bulb.set_rainbow(time)
         await bulb.set_transition_time(1000)
 
